@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -13,22 +13,27 @@
 
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
-
+#include <QWindow>
+namespace
+{
+static const char myInsertHtmlDialogConfigGroupName[] = "InsertHtmlDialog";
+}
 namespace KPIMTextEdit
 {
 class InsertHtmlDialogPrivate
 {
 public:
-    InsertHtmlDialogPrivate(InsertHtmlDialog *qq)
+    explicit InsertHtmlDialogPrivate(InsertHtmlDialog *qq)
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Insert HTML"));
         auto lay = new QVBoxLayout(q);
-        QLabel *label = new QLabel(i18n("Insert HTML tags and texts:"));
+        auto label = new QLabel(i18n("Insert HTML tags and texts:"));
         lay->addWidget(label);
         editor = new InsertHtmlEditor;
         editor->setSpellCheckingSupport(false);
@@ -40,7 +45,7 @@ public:
         label->setFont(font);
         label->setTextFormat(Qt::PlainText);
         lay->addWidget(label);
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
+        auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         okButton = buttonBox->button(QDialogButtonBox::Ok);
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
         okButton->setText(i18nc("@action:button", "Insert"));
@@ -90,17 +95,17 @@ QString InsertHtmlDialog::html() const
 
 void InsertHtmlDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "InsertHtmlDialog");
-    const QSize sizeDialog = group.readEntry("Size", QSize(640, 480));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(640, 480));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myInsertHtmlDialogConfigGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void InsertHtmlDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "InsertHtmlDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), myInsertHtmlDialogConfigGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 }
 
