@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -19,7 +19,7 @@ using namespace KPIMTextEdit;
 class InsertTableWidget::InsertTableWidgetPrivate
 {
 public:
-    InsertTableWidgetPrivate(InsertTableWidget *qq)
+    explicit InsertTableWidgetPrivate(InsertTableWidget *qq)
         : q(qq)
     {
         mRows = new QSpinBox;
