@@ -8,7 +8,6 @@
 
 #include "kpimtextedit_private_export.h"
 #include "texteditfindbarbase.h"
-#include <QTextDocument>
 #include <QWidget>
 
 class QAction;
@@ -34,9 +33,6 @@ public:
 
     Q_REQUIRED_RESULT QString searchText() const;
 
-private Q_SLOTS:
-    void slotAutoSearch(const QString &str);
-
 Q_SIGNALS:
     void findNext();
     void findPrev();
@@ -46,6 +42,7 @@ Q_SIGNALS:
     void searchStringEmpty(bool);
 
 private:
+    void slotAutoSearch(const QString &str);
     void slotRegularExpressionChanged(bool b);
     QLineEdit *const mSearch;
     QAction *mCaseSensitiveAct = nullptr;
